# OpenMDAO Partition Tree and N2 diagram.

× Instructions

Left clicking on a node in the partition tree will navigate to that node. Right clicking on a node in the partition tree will collapse/uncollapse it. A click on any element in the N^2 diagram will allow those arrows to persist.

Collapse Depth
Font Size 8px 9px 10px 11px 12px 13px 14px
Model Height 600px 650px 700px 750px 800px 850px 900px 950px 1000px 2000px 3000px 4000px
{d3_lib} {awesomplete_lib} {vk_beautify_lib} {{model_data}} {constants_lib} {modal_lib} {svg_lib} {search_lib} {legend_lib} {draw_lib} {ptn2_lib}